|PyPI Version| |Build Status| |Lint Status| |Coverage Status| |Python Version|

A suite of command-line tools for working with OCDS data to:

* create compiled releases, versioned releases and record packages
* upgrade from an old version of OCDS to a new version
* detect the format of an OCDS file
* wrap releases in a release package, or records in a record package
* combine small packages into large packages
* split large packages into small packages
* generate a spreadsheet version of a JSON schema

If you are viewing this on GitHub or PyPI, open the `full documentation <https://ocdskit.readthedocs.io/>`__ for additional details.

.. |PyPI Version| image:: https://img.shields.io/pypi/v/ocdskit.svg
   :target: https://pypi.org/project/ocdskit/
.. |Build Status| image:: https://github.com/open-contracting/ocdskit/workflows/CI/badge.svg
.. |Lint Status| image:: https://github.com/open-contracting/ocdskit/workflows/Lint/badge.svg
.. |Coverage Status| image:: https://coveralls.io/repos/github/open-contracting/ocdskit/badge.svg?branch=main
   :target: https://coveralls.io/github/open-contracting/ocdskit?branch=main
.. |Python Version| image:: https://img.shields.io/pypi/pyversions/ocdskit.svg
   :target: https://pypi.org/project/ocdskit/
